ChatKitClient class abstract

Abstract interface for ChatKit API communication

Implementers

Constructors

ChatKitClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMessage(ThreadAddMessageRequest request) Future<StreamResult>
Add a message to an existing thread
addToolOutput(ThreadAddToolOutputRequest request) Future<StreamResult>
Submit tool call output
createAttachment(AttachmentCreateRequest request) Future<Attachment>
Create an attachment upload descriptor
createThread(ThreadCreateRequest request) Future<StreamResult>
Create a new thread with initial message
customAction(ThreadCustomActionRequest request) Future<StreamResult>
Execute a custom action (widget)
deleteAttachment(AttachmentDeleteRequest request) Future<void>
Delete an attachment
deleteThread(ThreadDeleteRequest request) Future<void>
Delete a thread
dispose() → void
Dispose resources
getThread(ThreadGetByIdRequest request) Future<Thread>
Get a thread by ID
listItems(ItemsListRequest request) Future<Page<ThreadItem>>
List items in a thread
listThreads(ThreadListRequest request) Future<Page<ThreadMetadata>>
List threads
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryAfterItem(ThreadRetryRequest request) Future<StreamResult>
Retry from a specific item
submitFeedback(ItemsFeedbackRequest request) Future<void>
Submit feedback on items
toString() String
A string representation of this object.
inherited
updateThread(ThreadUpdateRequest request) Future<void>
Update thread title

Operators

operator ==(Object other) bool
The equality operator.
inherited