CheckboxNode class

Inheritance

Constructors

CheckboxNode({String? name, String? label, bool checked = false})
const
CheckboxNode.fromJson(Map<String, dynamic> json)
factory

Properties

checked bool
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited