ImageAttachment class

Inheritance

Constructors

ImageAttachment({required String id, required String name, required String mimeType, String? previewUrl, String? threadId, AttachmentUploadDescriptor? uploadDescriptor, Map<String, dynamic>? metadata})
const
ImageAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
mimeType String
final
name String
final
previewUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadId String?
final
type String
no setteroverride
uploadDescriptor AttachmentUploadDescriptor?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited