SseConnection class

Represents an active SSE connection that can be cancelled

Constructors

SseConnection({required Stream<Map<String, dynamic>> eventStream, required VoidCallback cancel})

Properties

cancel VoidCallback
Cancel the connection
final
eventStream Stream<Map<String, dynamic>>
Stream of parsed SSE event JSON objects
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited