ThreadStatus class sealed

Thread status sealed class hierarchy.

Represents the lifecycle state of a thread:

  • ActiveStatus: Thread is open and accepting new messages.
  • LockedStatus: Thread is locked (e.g., while AI is responding).
  • ClosedStatus: Thread is closed and no longer accepts messages.
Implementers

Constructors

ThreadStatus.fromJson(Map<String, dynamic> json)
Deserializes a ThreadStatus from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ThreadStatus to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited